@@ -44,7 +44,7 @@ sub get_test_call {
         return @call if $call[0]->can('FENNEC');
     }
 
-    return( @$runner );
+    return( $runner ? @$runner : ( "UNKNOWN", "UNKNOWN", 0 ) );
 }
 
 sub tb_ok         { Test::Builder->new->ok( @_ )        }
@@ -53,12 +53,6 @@ sub tb_skip       { Test::Builder->new->skip( @_ )      }
 sub tb_todo_start { Test::Builder->new->todo_start( @_ )}
 sub tb_todo_end   { Test::Builder->new->todo_end        }
 
-sub tb2_ok         { croak "Fennec does not yet support Test::Builder2" }
-sub tb2_diag       { croak "Fennec does not yet support Test::Builder2" }
-sub tb2_skip       { croak "Fennec does not yet support Test::Builder2" }
-sub tb2_todo_start { croak "Fennec does not yet support Test::Builder2" }
-sub tb2_todo_end   { croak "Fennec does not yet support Test::Builder2" }
-
 1;
 
 __END__
